@@ -10,9 +10,7 @@
 
 #include <KUnitConversion/Converter>
 
-Element::Element()
-{
-}
+Element::Element() = default;
 
 QVariant Element::dataAsVariant(ChemicalDataObject::BlueObelisk type) const
 {
@@ -21,7 +19,7 @@ QVariant Element::dataAsVariant(ChemicalDataObject::BlueObelisk type) const
             return o.value();
         }
     }
-    return QVariant();
+    return {};
 }
 
 QVariant Element::dataAsVariant(ChemicalDataObject::BlueObelisk type, int unit) const
@@ -32,10 +30,10 @@ QVariant Element::dataAsVariant(ChemicalDataObject::BlueObelisk type, int unit)
                 return o.value();
             }
             KUnitConversion::Value data(o.value().toDouble(), KUnitConversion::UnitId(o.unit()));
-            return QVariant(data.convertTo(KUnitConversion::UnitId(unit)).number());
+            return {data.convertTo(KUnitConversion::UnitId(unit)).number()};
         }
     }
-    return QVariant();
+    return {};
 }
 
 QString Element::dataAsString(ChemicalDataObject::BlueObelisk type) const
@@ -53,7 +51,7 @@ QString Element::dataAsStringWithUnit(ChemicalDataObject::BlueObelisk type, int
     QString valueAndUnit(QString::number(dataAsVariant(type, unit).toDouble(), 'g', 4));
 
     if (valueAndUnit.isEmpty()) {
-        return QString();
+        return {};
     }
 
     valueAndUnit.append(" ");
@@ -61,16 +59,14 @@ QString Element::dataAsStringWithUnit(ChemicalDataObject::BlueObelisk type, int
     return valueAndUnit;
 }
 
-Element::~Element()
-{
-}
+Element::~Element() = default;
 
-void Element::addData(const ChemicalDataObject& o)
+void Element::addData(const ChemicalDataObject &o)
 {
     dataList.append(o);
 }
 
-void Element::addData(const QVariant& value, ChemicalDataObject::BlueObelisk type)
+void Element::addData(const QVariant &value, ChemicalDataObject::BlueObelisk type)
 {
     ChemicalDataObject tmp(value, type);
     dataList.append(tmp);
